
# ddnss.de
This module updates ddnss IP address only on IP change.

# Usage
```
define ddnss.updater fhempy ddnssde USERNAME PASSWORD
```

USERNAME = ddnss.de username
PASSWORD = ddnss.de password

Wait a minute and select the hostname to update from hostname attribute afterwards.
